import { ParsedType } from "./getParsedType.js";
export declare const IssueCode: {
    invalid_key_type: "invalid_key_type";
    invalid_type: "invalid_type";
    missing_keys: "missing_keys";
    unrecognized_keys: "unrecognized_keys";
    not_ready: "not_ready";
    too_small: "too_small";
    too_big: "too_big";
    query_error: "query_error";
    invalid_string: "invalid_string";
    invalid_join_type: "invalid_join_type";
    invalid_join: "invalid_join";
};
export type IssueCode = keyof typeof IssueCode;
export interface InvalidTypeIssue {
    code: typeof IssueCode.invalid_type;
    expected: (ParsedType | "not null" | "not undefined") | (ParsedType | "not null" | "not undefined")[];
    received: ParsedType;
}
export interface UnrecognizedKeysIssue {
    code: typeof IssueCode.unrecognized_keys;
    keys: string[];
}
export interface InvalidKeyTypeIssue extends Omit<InvalidTypeIssue, "code"> {
    code: typeof IssueCode.invalid_key_type;
    objectKey: string;
}
export interface MissingKeysIssue {
    code: typeof IssueCode.missing_keys;
    keys: string[];
}
export interface NotReadyIssue {
    code: typeof IssueCode.not_ready;
}
export interface TooSmallIssue {
    code: typeof IssueCode.too_small;
    minimum: number | bigint | string;
    inclusive?: boolean;
    exact?: boolean;
    type: "array" | "number" | "arguments" | "keys";
}
export interface TooBigIssue {
    code: typeof IssueCode.too_big;
    maximum: number | bigint | string;
    inclusive?: boolean;
    exact?: boolean;
    type: "array" | "keys" | "arguments" | "depth";
}
export type QueryErrorIssue = {
    code: typeof IssueCode.query_error;
    errorMessage: string;
};
export interface InvalidStringIssue {
    code: typeof IssueCode.invalid_string;
    expected: string | string[];
    received: string;
}
export interface InvalidJoinTypeIssue extends Omit<InvalidStringIssue, "code"> {
    code: typeof IssueCode.invalid_join_type;
}
export interface InvalidJoinIssue {
    code: typeof IssueCode.invalid_join;
    type: "class" | "database" | "duplicate";
}
export type IssueWithoutMessage = InvalidKeyTypeIssue | InvalidTypeIssue | MissingKeysIssue | UnrecognizedKeysIssue | NotReadyIssue | TooSmallIssue | TooBigIssue | QueryErrorIssue | InvalidStringIssue | InvalidJoinTypeIssue | InvalidJoinIssue;
export type Issue = IssueWithoutMessage & {
    message: string;
};
export declare class PgTError extends Error {
    issue: Issue;
    get error(): Issue;
    constructor(issue: Issue);
    toString(): string;
    get message(): string;
    get code(): "invalid_key_type" | "invalid_type" | "missing_keys" | "unrecognized_keys" | "not_ready" | "too_small" | "too_big" | "query_error" | "invalid_string" | "invalid_join_type" | "invalid_join";
}
export type ErrorMap = (issue: IssueWithoutMessage) => {
    message: string;
};
