import { defineUntypedSchema } from "untyped";
import bundleSchema from "./BundleConfig.js";
const schema = defineUntypedSchema({
    directory: {
        $default: "__generated__",
        $resolve: value => (typeof value === "string" ? value : "__generated__"),
    },
    bundle: bundleSchema,
    debug: {
        $default: false,
        $resolve: Boolean,
    },
    debugFileName: {
        $default: "debug_{{ TIMESTAMP }}.json",
        $resolve: value => (typeof value === "string" ? value : "debug_{{ TIMESTAMP }}.json"),
    },
    defaultFormatter: {
        $default: "pascal-case",
        $resolve: value => (typeof value === "string" ? value : "pascal-case"),
    },
    domainTypeName: {
        $default: "{{ TYPE_NAME | default }}",
        $resolve: value => (typeof value === "string" ? value : "{{ TYPE_NAME | default }}"),
    },
    domainFileName: {
        $default: "_custom_types.ts",
        $resolve: value => (typeof value === "string" ? value : "_custom_types.ts"),
    },
    domainDataTypeName: {
        $default: "{{ TYPE_NAME | default }}Data",
        $resolve: value => (typeof value === "string" ? value : "{{ TYPE_NAME | default }}Data"),
    },
    domainDataFileName: {
        $default: "_custom_types.ts",
        $resolve: value => (typeof value === "string" ? value : "_custom_types.ts"),
    },
    enumTypeName: {
        $default: "{{ TYPE_NAME | default }}",
        $resolve: value => (typeof value === "string" ? value : "{{ TYPE_NAME | default }}"),
    },
    enumFileName: {
        $default: "databases/{{ DATABASE_NAME }}/enums/{{ TYPE_NAME }}.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME }}/enums/{{ TYPE_NAME }}.ts"),
    },
    primaryKeyTypeName: {
        $default: "{{ TABLE_NAME | default }}PrimaryKey",
        $resolve: value => (typeof value === "string" ? value : "{{ TABLE_NAME | default }}PrimaryKey"),
    },
    primaryKeyFileName: {
        $default: "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts"),
    },
    tableTypeName: {
        $default: "{{ TABLE_NAME | default }}",
        $resolve: value => (typeof value === "string" ? value : "{{ TABLE_NAME | default }}"),
    },
    tableFileName: {
        $default: "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts"),
    },
    tableDataTypeName: {
        $default: "{{ TABLE_NAME | default }}Data",
        $resolve: value => (typeof value === "string" ? value : "{{ TABLE_NAME | default }}Data"),
    },
    tableDataFileName: {
        $default: "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts"),
    },
    tableInsertParametersTypeName: {
        $default: "{{ TABLE_NAME | default }}InsertParameters",
        $resolve: value => (typeof value === "string" ? value : "{{ TABLE_NAME | default }}InsertParameters"),
    },
    tableInsertParametersFileName: {
        $default: "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts"),
    },
    tableInsertParametersDataTypeName: {
        $default: "{{ TABLE_NAME | default }}InsertParametersData",
        $resolve: value => (typeof value === "string" ? value : "{{ TABLE_NAME | default }}InsertParametersData"),
    },
    tableInsertParametersDataFileName: {
        $default: "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts"),
    },
    schemaTypeName: {
        $default: "{{ SCHEMA_NAME | default }}",
        $resolve: value => (typeof value === "string" ? value : "{{ SCHEMA_NAME | default }}"),
    },
    schemaFileName: {
        $default: "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}.ts"),
    },
    schemaDataTypeName: {
        $default: "{{ SCHEMA_NAME | default }}Data",
        $resolve: value => (typeof value === "string" ? value : "{{ SCHEMA_NAME | default }}Data"),
    },
    schemaDataFileName: {
        $default: "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}.ts"),
    },
    databaseTypeName: {
        $default: "{{ DATABASE_NAME | default }}",
        $resolve: value => (typeof value === "string" ? value : "{{ DATABASE_NAME | default }}"),
    },
    databaseFileName: {
        $default: "databases/{{ DATABASE_NAME }}.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME }}.ts"),
    },
    databaseDataTypeName: {
        $default: "{{ DATABASE_NAME | default }}Data",
        $resolve: value => (typeof value === "string" ? value : "{{ DATABASE_NAME | default }}Data"),
    },
    databaseDataFileName: {
        $default: "databases/{{ DATABASE_NAME }}.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME }}.ts"),
    },
    fullExportTypeName: {
        $default: "Databases",
        $resolve: value => (typeof value === "string" ? value : "Databases"),
    },
    fullExportFileName: {
        $default: "index.ts",
        $resolve: value => (typeof value === "string" ? value : "index.ts"),
    },
    fullExportDataTypeName: {
        $default: "DatabasesData",
        $resolve: value => (typeof value === "string" ? value : "DatabasesData"),
    },
    fullExportDataFileName: {
        $default: "index.ts",
        $resolve: value => (typeof value === "string" ? value : "index.ts"),
    },
    columnTypeOverrides: {
        $default: {},
        $resolve: value => {
            if (typeof value === "object")
                return value;
            return {};
        },
    },
    columnParserOverrides: {
        $default: {},
        $resolve: value => {
            if (typeof value === "object")
                return value;
            return {};
        },
    },
    typeOverrides: {
        $default: {},
        $resolve: value => {
            if (typeof value === "object")
                return value;
            return {};
        },
    },
    parserOverrides: {
        $default: {},
        $resolve: value => {
            if (typeof value === "object")
                return value;
            return {};
        },
    },
});
export default schema;
//# sourceMappingURL=TypesConfig.js.map